YARP 2.3.4 (2011-05-27)                                                {#v2_3_4}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.3...v2.3.4`):

```
   125	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    30	Lorenzo Natale <lorenzo.natale@iit.it>
    14	Ugo Pattacini <ugo.pattacini@iit.it>
    10	Alessandro Scalzo <alessandro.scalzo@iit.it>
     4	Daniel Krieg <krieg@fias.uni-frankfurt.de>
     4	Marco Randazzo <marco.randazzo@iit.it>
     3	Vadim Tikhanoff <vadim.tikhanoff@iit.it>
     1	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
     1	Francesco Nori <francesco.nori@iit.it>
```
